ethstats

package
v0.0.0-...-7b56087 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 17, 2018 License: GPL-3.0 Imports: 23 Imported by: 3

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Service

type Service struct {
	// contains filtered or unexported fields
}

Service implements an Tstchain netstats reporting daemon that pushes local chain statistics up to a monitoring server.

func New

func New(url string, ethServ *eth.Tstchain, lesServ *les.LightTstchain) (*Service, error)

New returns a monitoring service ready for stats reporting.

func (*Service) APIs

func (s *Service) APIs() []rpc.API

APIs implements node.Service, returning the RPC API endpoints provided by the stats service (nil as it doesn't provide any user callable APIs).

func (*Service) Protocols

func (s *Service) Protocols() []p2p.Protocol

Protocols implements node.Service, returning the P2P network protocols used by the stats service (nil as it doesn't use the devp2p overlay network).

func (*Service) Start

func (s *Service) Start(server *p2p.Server) error

Start implements node.Service, starting up the monitoring and reporting daemon.

func (*Service) Stop

func (s *Service) Stop() error

Stop implements node.Service, terminating the monitoring and reporting daemon.

Jump to